@@ -67,7 +67,7 @@ The operators and their general meaning are thus:
 =head1 METHODS
 
 =head2 method new
-    
+
     method new(Str :$template) returns URI::Template
 
 The constructor of the class.  The C<$template> must be a valid URI template if
@@ -90,7 +90,7 @@ C<X::InvalidTemplate> exception will be thrown.
 A read/write public accessor for the template.  If this parameter is not set by
 the accessor it must be set using C<template> before C<process> is called.
 
-Because of the way the template is parsed it will only be done once for any 
+Because of the way the template is parsed it will only be done once for any
 given C<URI::Template> object, so setting this after C<process> has been called
 for the first time will have no effect.  If you need a different template it is
 recommended to use a different object.
@@ -98,7 +98,7 @@ recommended to use a different object.
 
 =end pod
 
-class URI::Template:ver<v0.0.3>:auth<github:jonathanstowe> {
+class URI::Template:ver<0.0.7>:auth<github:jonathanstowe>:api<1.0> {
 
     has Str $.template is rw;
 
@@ -119,7 +119,7 @@ class URI::Template:ver<v0.0.3>:auth<github:jonathanstowe> {
         has Int $.max-length;
         has Bool $.explode;
 
-        method get-value(Str $operator, %vars) returns Str {
+        method get-value(Str $operator, %vars --> Str ) {
             my Str $value;
 
             if %vars{$!name}:exists {
@@ -156,7 +156,7 @@ class URI::Template:ver<v0.0.3>:auth<github:jonathanstowe> {
                 my $joiner = self!get-joiner($operator);
                 my &exp = self!get-exploder($operator);
                 my Str $exp-value = @value.map(&uri-encode-component).map(&exp).join($joiner);
-    
+
                 $exp-value does PreEncoded;
                 if self!was-exploded($operator) {
                     $exp-value does PreExploded;
@@ -169,7 +169,7 @@ class URI::Template:ver<v0.0.3>:auth<github:jonathanstowe> {
             }
         }
 
-        method !was-exploded(Str $operator) returns Bool {
+        method !was-exploded(Str $operator --> Bool ) {
             my Bool $ret = False;
             if $operator.defined {
                 if self.explode {
@@ -182,7 +182,7 @@ class URI::Template:ver<v0.0.3>:auth<github:jonathanstowe> {
         }
 
         #! return a closure to handle the array explosion
-        method !get-exploder(Str $operator) returns Callable {
+        method !get-exploder(Str $operator --> Callable ) {
 
             my &exp =  sub ( $val ) {
                 my $exp-val = $val;
@@ -235,7 +235,7 @@ class URI::Template:ver<v0.0.3>:auth<github:jonathanstowe> {
         );
 
         #| Get the appropriate character to join elements
-        method !get-joiner(Str $operator) returns Str {
+        method !get-joiner(Str $operator --> Str ) {
             my $joiner = self.explode ?? $operator.defined ?? %joiners{$operator} !! ',' !! ',';
             $joiner;
         }
@@ -255,7 +255,7 @@ class URI::Template:ver<v0.0.3>:auth<github:jonathanstowe> {
         }
 
         #| Returns the appropriate encoding sub for the operator
-        method !get-encoder(Str $operator) returns Callable {
+        method !get-encoder(Str $operator --> Callable ) {
             my &encoder = do if $operator.defined {
                 given $operator {
                     when /<[\+\#\;\.]>/ {
@@ -274,7 +274,7 @@ class URI::Template:ver<v0.0.3>:auth<github:jonathanstowe> {
 
         #| Returns the appropriate encoding sub for the operator
         #| this is special for the hash case for the time being
-        method !get-hash-encoder(Str $operator) returns Callable {
+        method !get-hash-encoder(Str $operator --> Callable ) {
             my &encoder = do if $operator.defined {
                 given $operator {
                     when /<[\+\#]>/ {
@@ -292,7 +292,7 @@ class URI::Template:ver<v0.0.3>:auth<github:jonathanstowe> {
         }
 
         #| encode the string if it it needed
-        method !encode-expanded(Str $operator, Str $value) returns Str {
+        method !encode-expanded(Str $operator, Str $value --> Str ) {
             my $res = do if $value ~~ PreEncoded {
                 $value;
             }
@@ -313,7 +313,7 @@ class URI::Template:ver<v0.0.3>:auth<github:jonathanstowe> {
                     $res = (self!get-primer($operator) // '') ~ $eq;
                 }
                 $res ~= self!encode-expanded($operator, $val);
-            } 
+            }
             elsif $val.defined {
                $res = self!get-primer($operator);
             }
@@ -323,7 +323,7 @@ class URI::Template:ver<v0.0.3>:auth<github:jonathanstowe> {
             $res;
         }
 
-        method !get-primer(Str $operator) returns Str {
+        method !get-primer(Str $operator --> Str ) {
             my Str $primer = do given $operator {
                 when '&' {
                     $!name ~ '=';
@@ -373,7 +373,7 @@ class URI::Template:ver<v0.0.3>:auth<github:jonathanstowe> {
         has $.operator;
         has Variable @.variables;
 
-        method process(%vars) returns Str {
+        method process(%vars --> Str ) {
             my Str $str;
 
             my @processed-bits = ();
@@ -420,7 +420,7 @@ class URI::Template:ver<v0.0.3>:auth<github:jonathanstowe> {
 
     has Grammar $.grammar = our grammar Grammar {
         rule TOP {
-            <bits>* [ <expression>+ ]* %% <bits>+ 
+            <bits>* [ <expression>+ ]* %% <bits>+
         }
 
         token bits { <-[{]>+ }
@@ -430,9 +430,9 @@ class URI::Template:ver<v0.0.3>:auth<github:jonathanstowe> {
         }
 
         regex operator {
-            <reserved>          || 
-            <fragment>          || 
-            <label-dot>         || 
+            <reserved>          ||
+            <fragment>          ||
+            <label-dot>         ||
             <path-slash>        ||
             <path-semicolon>    ||
             <form-ampersand>    ||
@@ -510,7 +510,7 @@ class URI::Template:ver<v0.0.3>:auth<github:jonathanstowe> {
 
         method expression($/) {
             my $operator =  $/<operator>.defined ?? $/<operator>.Str !! Str;
-            my @variables = $/<variable>.list.map({ $_.made }); 
+            my @variables = $/<variable>.list.map({ $_.made });
             @!PARTS.push(Expression.new(:$operator, :@variables));
         }
 
@@ -548,7 +548,7 @@ class URI::Template:ver<v0.0.3>:auth<github:jonathanstowe> {
 
             if $!template.defined {
 
-            
+
                 my $actions = Actions.new;
 
                 my $match = URI::Template::Grammar.parse($!template, :$actions);
@@ -567,7 +567,7 @@ class URI::Template:ver<v0.0.3>:auth<github:jonathanstowe> {
         @!parts;
     }
 
-    method process(*%vars) returns Str {
+    method process(*%vars --> Str ) {
         my Str $string;
 
         for self.parts -> $part {
